<?php
/**
 * CommonPlugin for phplist.
 *
 * This file is a part of CommonPlugin.
 *
 * @category  phplist
 *
 * @author    Duncan Cameron
 * @copyright 2011-2018 Duncan Cameron
 * @license   http://www.gnu.org/licenses/gpl.html GNU General Public License, Version 3
 */

/**
 * This file contains the Russian text.
 */
return [
//  CommonPlugin.php
    ['phpinfo', 'phpinfo'],
    ['config.php', 'config.php'],
    ['php session', 'php session'],
//  Pager.php
    ['Showing %d to %d of %d', 'Показано с %d по %d из %d'],
    ['no_results', 'Нет данных для отображения'],
//  Toolbar.php
    ['help', 'Справка'],
//  Widget.php
    ['Select attributes', 'Выбрать атрибуты'],
//  General
    ['top', 'вверх'],
//  widget_attributeform.tpl.php
    ['Search for', 'Найти'],
    ['All', 'Все'],
    ['confirmed only', 'только подтвержденные'],
    ['unconfirmed only', 'только не подтвержденные'],
    ['blacklisted only', 'только заблокированные'],
    ['not blacklisted only', 'только не заблокированные'],
//  ExportCSVAsync.php
    ['Exporting, this may take a while', 'Идет экспорт, это может занять некоторое время'],
    ['Generating the export data', 'Подготовка данных для экспорта'],
    ['Exported %d of %d %d%%', 'Экспортировано %d из %d %d%%'],
];
